@@ -7,8 +7,10 @@ use version;
 use Carp qw(croak cluck);
 use Data::Dumper;
 use File::Copy;
+use File::Path qw(make_path);
 use File::Find::Rule;
 use PPI;
+use STEVEB::Dist::Mgr::FileData;
 use Tie::File;
 
 use Exporter qw(import);
@@ -18,24 +20,35 @@ our @EXPORT_OK = qw(
     add_repository
     bump_version
     get_version_info
+    ci_github
+    ci_badges
+    manifest_skip
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use constant {
+    GITHUB_CI_FILE      => 'github_ci_default.yml',
+    GITHUB_CI_PATH      => '.github/workflows/',
     FSTYPE_IS_DIR       => 1,
     FSTYPE_IS_FILE      => 2,
-
     DEFAULT_DIR         => 'lib/',
 };
 
 # Public
 
 #TODO:
+# re-create the module-starter version of the module file to conform
+# with layout
+
+# CI badges
+# *** check if in root of distribution
+
+# module-starter
+# coveralls
+# git init or pull manually created new repo?
 # unlink unwanted files & dirs (xt/, ignore.txt, README)
-# travis-ci
-# appveyor
 # MANIFEST.SKIP
 # .gitignore
 
@@ -75,14 +88,14 @@ sub bump_version {
     _validate_version($version);
     _validate_fs_entry($fs_entry);
 
-    my @module_files = _find_module_files($fs_entry);
+    my @module_files = _module_find_files($fs_entry);
 
     my %files;
 
     for (@module_files) {
-        my $current_version = _extract_file_version($_);
-        my $version_line    = _extract_file_version_line($_);
-        my @file_contents   = _fetch_file_contents($_);
+        my $current_version = _module_extract_file_version($_);
+        my $version_line    = _module_extract_file_version_line($_);
+        my @file_contents   = _module_fetch_file_contents($_);
 
         if (! defined $version_line) {
             next;
@@ -119,7 +132,7 @@ sub bump_version {
 
         if (! $dry_run) {
             # Write out the actual file
-            _write_module_file($_, $mem_file);
+            _module_write_file($_, $mem_file);
         }
     }
     return \%files;
@@ -129,30 +142,100 @@ sub get_version_info {
 
     _validate_fs_entry($fs_entry);
 
-    my @module_files = _find_module_files($fs_entry);
+    my @module_files = _module_find_files($fs_entry);
 
     my %version_info;
 
     for (@module_files) {
-        my $version = _extract_file_version($_);
+        my $version = _module_extract_file_version($_);
         $version_info{$_} = $version;
     }
 
     return \%version_info;
 }
+sub ci_badges {
+    if (scalar @_ != 3) {
+        croak("ci_badges() needs \$author, \$repo and \$fs_entry sent in");
+    }
+
+    my ($author, $repo, $fs_entry) = @_;
+
+    for (_module_find_files($fs_entry)) {
+        _module_insert_ci_badges($author, $repo, $_);
+    }
+
+    return 0;
+}
+sub ci_github {
+    my ($os) = @_;
+
+    if (defined $os && ref $os ne 'ARRAY') {
+        croak("\$os parameter to github_ci() must be an array ref");
+    }
+
+    my @contents = _ci_github_file($os);
+    _ci_github_write_file(\@contents);
+
+    return @contents;
+}
+sub manifest_skip {
+    my ($dir) = @_;
+
+    $dir //= '.';
+
+    my @content = _manifest_skip_file();
+
+    _manifest_skip_write_file($dir, \@content);
+
+    return @content;
+}
+
+# CI related
+
+sub _ci_github_write_file {
+    my ($contents) = @_;
+
+    if (! ref $contents eq 'ARRAY') {
+        croak("_write_github_ci_file() requires an array ref of contents");
+    }
+
+    my $ci_file //= GITHUB_CI_PATH . GITHUB_CI_FILE;
+
+    make_path(GITHUB_CI_PATH) if ! -d GITHUB_CI_PATH;
+
+    open my $fh, '>', $ci_file or die $!;
+
+    print $fh "$_\n" for @$contents;
+}
 
 # Module related
 
-sub _find_module_files {
-    my ($fs_entry) = @_;
+sub _module_find_files {
+    my ($fs_entry, $module) = @_;
 
     $fs_entry //= DEFAULT_DIR;
 
+    if (defined $module) {
+        $module =~ s/::/\//g;
+        $module .= '.pm';
+    }
+    else {
+        $module = '*.pm';
+    }
+
+
     return File::Find::Rule->file()
-        ->name('*.pm')
+        ->name($module)
         ->in($fs_entry);
 }
-sub _fetch_file_contents {
+sub _module_load {
+    my ($mod_file) = @_;
+    croak("_module_load() needs a module file name sent in") if ! defined $mod_file;
+
+    my $tie = tie my @mf, 'Tie::File', $mod_file;
+    return (\@mf, $tie);
+}
+sub _module_fetch_file_contents {
     my ($file) = @_;
 
     open my $fh, '<', $file
@@ -162,10 +245,10 @@ sub _fetch_file_contents {
     close $fh;
     return @contents;
 }
-sub _extract_file_version {
+sub _module_extract_file_version {
     my ($module_file) = @_;
 
-    my $version_line = _extract_file_version_line($module_file);
+    my $version_line = _module_extract_file_version_line($module_file);
 
     if (defined $version_line) {
 
@@ -191,7 +274,7 @@ sub _extract_file_version {
     }
     return undef;
 }
-sub _extract_file_version_line {
+sub _module_extract_file_version_line {
     my ($module_file) = @_;
 
     my $doc = PPI::Document->new($module_file);
@@ -209,7 +292,22 @@ sub _extract_file_version_line {
 
     return $version_line;
 }
-sub _write_module_file {
+sub _module_insert_ci_badges {
+    my ($author, $repo, $module_file) = @_;
+
+    my ($mf, $tie) = _module_load($module_file);
+
+    for (0..$#$mf) {
+        if ($mf->[$_] =~ /^=head1 NAME/) {
+            splice @$mf, $_+3, 0, _module_section_ci_badges($author, $repo);
+            last;
+        }
+    }
+    untie $tie;
+
+    return 0;
+}
+sub _module_write_file {
     my ($module_file, $content) = @_;
 
     open my $wfh, '>', $module_file or croak("Can't open '$module_file' for writing!: $!");
@@ -219,6 +317,20 @@ sub _write_module_file {
     close $wfh or croak("Can't close the temporary memory module file!: $!");
 }
 
+# MANIFEST.SKIP related
+
+sub _manifest_skip_write_file {
+    my ($dir, $content) = @_;
+
+    open my $fh, '>', "$dir/MANIFEST.SKIP" or die $!;
+
+    for (@$content) {
+        print $fh "$_\n"
+    }
+
+    return 0;
+}
+
 # Makefile related
 
 sub _makefile_load {
@@ -290,40 +402,6 @@ sub _makefile_insert_repository {
     return 0;
 }
 
-sub _makefile_section_meta_merge {
-    my @merge_section = (
-        "    META_MERGE => {",
-        "        'meta-spec' => { version => 2 },",
-        "        resources   => {",
-        "        },",
-        "    },"
-    );
-
-    return @merge_section;
-}
-sub _makefile_section_bugtracker {
-    my ($author, $repo) = @_;
-
-    return (
-        "            bugtracker => {",
-        "                web => 'https://github.com/$author/$repo/issues',",
-        "            },"
-    );
-
-}
-sub _makefile_section_repo {
-    my ($author, $repo) = @_;
-
-    return (
-    "            repository => {",
-    "                type => 'git',",
-    "                url => 'https://github.com/$author/$repo.git',",
-    "                web => 'https://github.com/$author/$repo',",
-    "            },"
-    );
-
-}
-
 # Validation related
 
 sub _validate_fs_entry {
